package com.ruoyi.order.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.order.mapper.TCanteenPaymentMapper;
import com.ruoyi.order.domain.TCanteenPayment;
import com.ruoyi.order.service.ITCanteenPaymentService;

/**
 * 支付记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@Service
public class TCanteenPaymentServiceImpl implements ITCanteenPaymentService 
{
    @Autowired
    private TCanteenPaymentMapper tCanteenPaymentMapper;

    /**
     * 查询支付记录
     * 
     * @param payId 支付记录主键
     * @return 支付记录
     */
    @Override
    public TCanteenPayment selectTCanteenPaymentByPayId(Long payId)
    {
        return tCanteenPaymentMapper.selectTCanteenPaymentByPayId(payId);
    }

    /**
     * 查询支付记录列表
     * 
     * @param tCanteenPayment 支付记录
     * @return 支付记录
     */
    @Override
    public List<TCanteenPayment> selectTCanteenPaymentList(TCanteenPayment tCanteenPayment)
    {
        return tCanteenPaymentMapper.selectTCanteenPaymentList(tCanteenPayment);
    }

    /**
     * 新增支付记录
     * 
     * @param tCanteenPayment 支付记录
     * @return 结果
     */
    @Override
    public int insertTCanteenPayment(TCanteenPayment tCanteenPayment)
    {
        return tCanteenPaymentMapper.insertTCanteenPayment(tCanteenPayment);
    }

    /**
     * 修改支付记录
     * 
     * @param tCanteenPayment 支付记录
     * @return 结果
     */
    @Override
    public int updateTCanteenPayment(TCanteenPayment tCanteenPayment)
    {
        return tCanteenPaymentMapper.updateTCanteenPayment(tCanteenPayment);
    }

    /**
     * 批量删除支付记录
     * 
     * @param payIds 需要删除的支付记录主键
     * @return 结果
     */
    @Override
    public int deleteTCanteenPaymentByPayIds(Long[] payIds)
    {
        return tCanteenPaymentMapper.deleteTCanteenPaymentByPayIds(payIds);
    }

    /**
     * 删除支付记录信息
     * 
     * @param payId 支付记录主键
     * @return 结果
     */
    @Override
    public int deleteTCanteenPaymentByPayId(Long payId)
    {
        return tCanteenPaymentMapper.deleteTCanteenPaymentByPayId(payId);
    }
}
