package com.ruoyi.order.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.order.domain.TCanteenPayment;
import com.ruoyi.order.service.ITCanteenPaymentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 支付记录Controller
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/order/payment")
public class TCanteenPaymentController extends BaseController
{
    @Autowired
    private ITCanteenPaymentService tCanteenPaymentService;

    /**
     * 查询支付记录列表
     */
    @PreAuthorize("@ss.hasPermi('order:payment:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCanteenPayment tCanteenPayment)
    {
        startPage();
        List<TCanteenPayment> list = tCanteenPaymentService.selectTCanteenPaymentList(tCanteenPayment);
        return getDataTable(list);
    }

    /**
     * 导出支付记录列表
     */
    @PreAuthorize("@ss.hasPermi('order:payment:export')")
    @Log(title = "支付记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCanteenPayment tCanteenPayment)
    {
        List<TCanteenPayment> list = tCanteenPaymentService.selectTCanteenPaymentList(tCanteenPayment);
        ExcelUtil<TCanteenPayment> util = new ExcelUtil<TCanteenPayment>(TCanteenPayment.class);
        util.exportExcel(response, list, "支付记录数据");
    }

    /**
     * 获取支付记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:payment:query')")
    @GetMapping(value = "/{payId}")
    public AjaxResult getInfo(@PathVariable("payId") Long payId)
    {
        return success(tCanteenPaymentService.selectTCanteenPaymentByPayId(payId));
    }

    /**
     * 新增支付记录
     */
    @PreAuthorize("@ss.hasPermi('order:payment:add')")
    @Log(title = "支付记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCanteenPayment tCanteenPayment)
    {
        return toAjax(tCanteenPaymentService.insertTCanteenPayment(tCanteenPayment));
    }

    /**
     * 修改支付记录
     */
    @PreAuthorize("@ss.hasPermi('order:payment:edit')")
    @Log(title = "支付记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCanteenPayment tCanteenPayment)
    {
        return toAjax(tCanteenPaymentService.updateTCanteenPayment(tCanteenPayment));
    }

    /**
     * 删除支付记录
     */
    @PreAuthorize("@ss.hasPermi('order:payment:remove')")
    @Log(title = "支付记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{payIds}")
    public AjaxResult remove(@PathVariable Long[] payIds)
    {
        return toAjax(tCanteenPaymentService.deleteTCanteenPaymentByPayIds(payIds));
    }
}
